Version 0.0.4:
- Moved role creation to manual script run
- Populated README with basic usage

Version 0.0.3:
- Fixed custom role creation for satgpt to grab target machine os/ shell
- Added pystac as install dependency for demos
- Added this CHANGELOG

Version 0.0.2:
- Integrated shell-gpt as a dependency using the custom role feature released in version 0.9.0